#!/usr/bin/python
# -*- coding: utf-8 -*-

from setuptools import find_packages, setup

setup(
    name='vasalskyy',
    version='0.2.5',
    author='vasalskyy',
    author_email='vasalskyyy@gmail.com',
    packages=find_packages(),
    include_package_data=True,
    description='Hello world package'
)